@@ -18,6 +18,26 @@ def ax_name(tab, qty):
 
 
 def preSymp(str):
+    """
+    returns a string ready to be passed to Sympy.
+
+    Sympy sometimes assumes the meaning of certain variables, this fuction
+    prevents that.
+
+    ex:
+        >>> import sympy as sp
+        >>> sp.sympify('N**2')
+        ... TypeError: unsupported operand type(s) for ** or pow(): 'function'
+         and'Integer'
+
+        Here sympy assumed that N was it's own function sympy.N. In the case
+        where you would want to use N as a variable instead, you could use:
+
+        >>> import sympy as sp
+        >>> from tablpy.extra_funcs import preSymp
+        >>> sp.sympify(preSymp('N**2'))
+        ... N**2
+    """
     str = str.replace("{", "__0__").replace("}", "__1__")
     pat = (r"\b(?!ln|log|sin|cos|tan|exp|atan|sqrt)\\?"
            r"[a-zA-Z]+[_0-9a-zA-Z({{)(}}),]*\b")
@@ -41,6 +61,18 @@ def roundUp(num):  # arrondis vers le haut à la bonne décimale
 
 # Détermine la formule d'incertitude pour une expression donnée
 def formule_incertitude(eq):
+    r"""
+    Returns a sympy expression of the uncertainty associated with a formula
+
+    ex:
+        >>> from tablpy.extra_funcs import formule_incertitude
+        >>> import sympy as sp
+
+        >>> eq = sp.sympify("(a+b)*c")
+        >>> formule_incertitude(eq)
+        ... sqrt(\Delta\!a**2*c**2 + \Delta\!b**2*c**2
+                 + \Delta\!c**2*(a + b)**2)
+    """
     eq = sp.sympify(eq)
     variables = list(eq.free_symbols)  # liste de tout les variables
     # liste de touts les incertitudes asssociées au variables
@@ -73,11 +105,15 @@ def isUncertain(string):
     return any([marqeur in str(string) for marqeur in marqeurs])
 
 
-def getTexIncert(x):
-    print(sp.latex(formule_incertitude(x)))
+def getTexIncert(eq):
+    print(sp.latex(formule_incertitude(eq)))
 
 
 def fastPlot(file):
+    """plots the two first colums of a data file"""
     array = np.genfromtxt(file, skip_header=True, delimiter="\t")
-    print(array)
     plt.plot(array[:, 0], array[:, 1])
+
+
+def rool(values, min, max):
+    return ((values+min) % max)-min
